@@ -15,7 +15,11 @@
 strlen <- function( s ) { return(nchar(s)) };
 
 strfindf <- function( s, p, start=1 ) {
-  if( strlen(s)<strlen(p) ) return(-1); ## 01/25/2006
+  if( length(s)!=1 || length(p)!=1 )
+    return(-1) ## 08/11/20008
+
+  if( strlen(s)<strlen(p) )
+    return(-1); ## 01/25/2006
   ls <- strlen(s);  lp <- strlen(p);
   if( ls < lp ) return(-1);
   if( ls-lp+1<start ) return(-1); ## 01/26/2006
@@ -29,13 +33,17 @@ strfindf <- function( s, p, start=1 ) {
 # 10/06/2005
 # find - from behind!
 strfindb <- function( s, p, start=strlen(s)-strlen(p) ) {
-  if( strlen(s)<strlen(p) ) return(-1); ## 01/25/2006
+  if( length(s)!=1 || length(p)!=1 )
+    return(-1) ## 08/11/2008
+
+  if( strlen(s)<strlen(p) )
+    return(-1); ## 01/25/2006
   lp <- strlen(p);
   for( i in seq(start,1,by=-1) ) {
     if( p==substring(s,i,i+lp-1) ) #@$%!!!
       return(i);
   }
-  return(-1); # not found    
+  return(-1); # not found
 }
 # get's the path of a file / executable
 str.getpath <- function( s ) {
@@ -52,24 +60,24 @@ str.getpath <- function( s ) {
   # return the substring
   return( substring( s, 1, loc1-1 ) );
 }
-  
+
 
 str.extract.after <- function( s, p='~' ) {
   loc <- strfindf( s,p );
-  if( loc==-1 ) return("");
+  if( loc == -1 ) return("");
   return( substring( s, loc+strlen(p) ) );
 }
 
 str.extract.afterb <- function( s, p='~' ) {
   loc <- strfindb( s,p );
-  if( loc==-1 ) return("");
+  if( loc == -1 ) return("");
   return( substring( s, loc+strlen(p) ) );
 }
 
 str.file.extension <- function( s, extension='txt' ){
   if( substring(extension,1,1)!="." ) #@$%!!!
     extension = paste(".",extension,sep="");
-  
+
   if( strlen(s) > strlen(extension) ){
     if( substring(s,strlen(s)-strlen(extension)+1) == extension )
       return( s );
@@ -91,7 +99,7 @@ strReplace <- function( str, find, repl )  {
 
   if( length(strList) <= 1 )
     return(str);
-  
+
   strRet <- strList[1];
   ##print( strRet );
   for( i in 2:length(strList) ){
